package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.ExamineConfig;
import com.ruoyi.system.service.IExamineConfigService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 审核角色配置Controller
 * 
 * @author boman
 * @date 2022-01-24
 */
@RestController
@RequestMapping("/system/examine")
public class ExamineConfigController extends BaseController
{
    @Autowired
    private IExamineConfigService examineConfigService;

    /**
     * 查询审核角色配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:examine:list')")
    @GetMapping("/list")
    public TableDataInfo list(ExamineConfig examineConfig)
    {
        startPage();
        List<ExamineConfig> list = examineConfigService.selectExamineConfigList(examineConfig);
        return getDataTable(list);
    }

    /**
     * 导出审核角色配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:examine:export')")
    @Log(title = "审核角色配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ExamineConfig examineConfig)
    {
        List<ExamineConfig> list = examineConfigService.selectExamineConfigList(examineConfig);
        ExcelUtil<ExamineConfig> util = new ExcelUtil<ExamineConfig>(ExamineConfig.class);
        util.exportExcel(response, list, "审核角色配置数据");
    }

    /**
     * 获取审核角色配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:examine:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(examineConfigService.selectExamineConfigById(id));
    }

    /**
     * 新增审核角色配置
     */
    @PreAuthorize("@ss.hasPermi('system:examine:add')")
    @Log(title = "审核角色配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ExamineConfig examineConfig)
    {
        return toAjax(examineConfigService.insertExamineConfig(examineConfig));
    }

    /**
     * 修改审核角色配置
     */
    @PreAuthorize("@ss.hasPermi('system:examine:edit')")
    @Log(title = "审核角色配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ExamineConfig examineConfig)
    {
        return toAjax(examineConfigService.updateExamineConfig(examineConfig));
    }

    /**
     * 删除审核角色配置
     */
    @PreAuthorize("@ss.hasPermi('system:examine:remove')")
    @Log(title = "审核角色配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(examineConfigService.deleteExamineConfigByIds(ids));
    }
}
