package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.common.core.domain.entity.ColumnNavigationBar;
import com.ruoyi.common.core.domain.entity.SysDept;
import org.apache.ibatis.annotations.Param;

/**
 * 栏目导航Mapper接口
 * 
 * @author boman
 * @date 2021-12-24
 */
public interface ColumnNavigationBarMapper 
{
    /**
     * 查询栏目导航
     *
     * @param columnId 栏目导航主键
     * @return 栏目导航
     */
    public ColumnNavigationBar selectColumnNavigationBarByColumnId(Long columnId);

    /**
     * 查询栏目导航列表
     *
     * @param columnNavigationBar 栏目导航
     * @return 栏目导航集合
     */
    public List<ColumnNavigationBar> selectColumnNavigationBarList(ColumnNavigationBar columnNavigationBar);

    /**
     * 门户获取首页各个部门标题
     * @param columnNavigationBar
     * @return
     */
    public List<ColumnNavigationBar> selectColumnNavigationBarListMenHu(ColumnNavigationBar columnNavigationBar);

    /**
     * 新增栏目导航
     *
     * @param columnNavigationBar 栏目导航
     * @return 结果
     */
    public int insertColumnNavigationBar(ColumnNavigationBar columnNavigationBar);

    /**
     * 修改栏目导航
     *
     * @param columnNavigationBar 栏目导航
     * @return 结果
     */
    public int updateColumnNavigationBar(ColumnNavigationBar columnNavigationBar);

    /**
     * 删除栏目导航
     *
     * @param columnId 栏目导航主键
     * @return 结果
     */
    public int deleteColumnNavigationBarByColumnId(Long columnId);

    /**
     * 批量删除栏目导航
     *
     * @param columnIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteColumnNavigationBarByColumnIds(Long[] columnIds);

    /**
     * 校验栏目导航名称是否唯一
     *
     * @param columnName 栏目导航名称
     * @param parentId 父部门ID
     * @return 结果
     */
    public ColumnNavigationBar checkColumnNameUnique(@Param("columnName") String columnName, @Param("parentId") Long parentId);

    /**
     * 根据ID查询所有子栏目导航（正常状态）
     *
     * @param columnId 栏目导航ID
     * @return 子栏目导航数
     */
    public int selectNormalChildrenColumnById(Long columnId);

    /**
     * 根据ID查询所有子栏目导航
     * @param columnId
     * @return
     */
    public List<ColumnNavigationBar> selectChildrenColumnById(Long columnId);

    /**
     * 修改子元素关系
     *
     * @param columns 子元素
     * @return 结果
     */
    public int updateColumnChildren(@Param("columns") List<ColumnNavigationBar> columns);

    /**
     * 修改所在栏目导航正常状态
     *
     * @param columnIds 栏目导航ID组
     */
    public void updateColumnStatusNormal(Long[] columnIds);


    /**
     * 是否存在栏目导航子节点
     * @param columnId
     * @return
     */
    public int hasChildByColumnId(Long columnId);

}
