package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.TreeSelect;
import com.ruoyi.common.core.domain.entity.ColumnNavigationBar;
import com.ruoyi.common.core.domain.entity.SysDept;

/**
 * 栏目导航Service接口
 * 
 * @author boman
 * @date 2021-12-24
 */
public interface IColumnNavigationBarService 
{
    /**
     * 查询栏目导航
     * 
     * @param columnId 栏目导航主键
     * @return 栏目导航
     */
    public ColumnNavigationBar selectColumnNavigationBarByColumnId(Long columnId);

    /**
     * 查询栏目导航列表
     * 
     * @param columnNavigationBar 栏目导航
     * @return 栏目导航集合
     */
    public List<ColumnNavigationBar> selectColumnNavigationBarList(ColumnNavigationBar columnNavigationBar);

    /**
     * 门户获取各个部分首页标题
     * @param columnNavigationBar
     * @return
     */
    public List<ColumnNavigationBar> selectColumnNavigationBarListMenHu(ColumnNavigationBar columnNavigationBar);

    /**
     * 新增栏目导航
     * 
     * @param columnNavigationBar 栏目导航
     * @return 结果
     */
    public int insertColumnNavigationBar(ColumnNavigationBar columnNavigationBar);

    /**
     * 修改栏目导航
     * 
     * @param columnNavigationBar 栏目导航
     * @return 结果
     */
    public int updateColumnNavigationBar(ColumnNavigationBar columnNavigationBar);

    /**
     * 批量删除栏目导航
     * 
     * @param columnIds 需要删除的栏目导航主键集合
     * @return 结果
     */
    public int deleteColumnNavigationBarByColumnIds(Long[] columnIds);

    /**
     * 删除栏目导航信息
     * 
     * @param columnId 栏目导航主键
     * @return 结果
     */
    public int deleteColumnNavigationBarByColumnId(Long columnId);


    /**
     * 构建前端所需要下拉树结构
     *
     * @param columnNavigationBars 栏目导航列表
     * @return 下拉树结构列表
     */
    public List<TreeSelect> buildColumnTreeSelect(List<ColumnNavigationBar> columnNavigationBars);


    /**
     * 构建前端所需要树结构
     *
     * @param columnNavigationBars 栏目导航列表
     * @return 树结构列表
     */
    public List<ColumnNavigationBar> buildColumnTree(List<ColumnNavigationBar> columnNavigationBars);

    /**
     * 校验栏目导航名称是否唯一
     *
     * @param columnNavigationBar 栏目导航信息
     * @return 结果
     */
    public String checkColumnNameUnique(ColumnNavigationBar columnNavigationBar);

    /**
     * 根据ID查询所有子栏目导航（正常状态）
     *
     * @param columnId 栏目导航ID
     * @return 子栏目导航数
     */
    public int selectNormalChildrenColumnById(Long columnId);

    /**
     * 是否存在栏目导航子节点
     *
     * @param columnId 栏目导航ID
     * @return 结果
     */
    public boolean hasChildByColumnId(Long columnId);

}
