package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.FriendLinkMapper;
import com.ruoyi.system.domain.FriendLink;
import com.ruoyi.system.service.IFriendLinkService;

/**
 * 友链导航Service业务层处理
 * 
 * @author boman
 * @date 2021-12-29
 */
@Service
public class FriendLinkServiceImpl implements IFriendLinkService 
{
    @Autowired
    private FriendLinkMapper friendLinkMapper;

    /**
     * 查询友链导航
     * 
     * @param linkId 友链导航主键
     * @return 友链导航
     */
    @Override
    public FriendLink selectFriendLinkByLinkId(Long linkId)
    {
        return friendLinkMapper.selectFriendLinkByLinkId(linkId);
    }

    /**
     * 查询友链导航列表
     * 
     * @param friendLink 友链导航
     * @return 友链导航
     */
    @Override
    public List<FriendLink> selectFriendLinkList(FriendLink friendLink)
    {
        return friendLinkMapper.selectFriendLinkList(friendLink);
    }

    /**
     * 新增友链导航
     * 
     * @param friendLink 友链导航
     * @return 结果
     */
    @Override
    public int insertFriendLink(FriendLink friendLink)
    {
        friendLink.setCreateTime(DateUtils.getNowDate());
        return friendLinkMapper.insertFriendLink(friendLink);
    }

    /**
     * 修改友链导航
     * 
     * @param friendLink 友链导航
     * @return 结果
     */
    @Override
    public int updateFriendLink(FriendLink friendLink)
    {
        friendLink.setUpdateTime(DateUtils.getNowDate());
        return friendLinkMapper.updateFriendLink(friendLink);
    }

    /**
     * 批量删除友链导航
     * 
     * @param linkIds 需要删除的友链导航主键
     * @return 结果
     */
    @Override
    public int deleteFriendLinkByLinkIds(Long[] linkIds)
    {
        return friendLinkMapper.deleteFriendLinkByLinkIds(linkIds);
    }

    /**
     * 删除友链导航信息
     * 
     * @param linkId 友链导航主键
     * @return 结果
     */
    @Override
    public int deleteFriendLinkByLinkId(Long linkId)
    {
        return friendLinkMapper.deleteFriendLinkByLinkId(linkId);
    }
}
