package com.ruoyi.system.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.MiniprogramQueryLog;
import com.ruoyi.system.mapper.MiniprogramQueryLogMapper;
import com.ruoyi.system.service.IMiniprogramQueryLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 小程序查询历史记录Service业务层处理
 *
 * @author boman
 * @date 2022-02-21
 */
@Service
public class MiniprogramQueryLogServiceImpl implements IMiniprogramQueryLogService {
    @Autowired
    private MiniprogramQueryLogMapper miniprogramQueryLogMapper;

    /**
     * 查询小程序查询历史记录
     *
     * @param logId 小程序查询历史记录主键
     * @return 小程序查询历史记录
     */
    @Override
    public MiniprogramQueryLog selectMiniprogramQueryLogByLogId(Long logId) {
        return miniprogramQueryLogMapper.selectMiniprogramQueryLogByLogId(logId);
    }

    /**
     * 查询小程序查询历史记录列表
     *
     * @param miniprogramQueryLog 小程序查询历史记录
     * @return 小程序查询历史记录
     */
    @Override
    public List<MiniprogramQueryLog> selectMiniprogramQueryLogList(MiniprogramQueryLog miniprogramQueryLog) {
        String queryPhone = miniprogramQueryLog.getQueryPhone();
        if(StringUtils.isBlank(queryPhone)){
            List<MiniprogramQueryLog> list = new ArrayList<>();
            return list;
        }
        return miniprogramQueryLogMapper.selectMiniprogramQueryLogList(miniprogramQueryLog);
    }

    /**
     * 新增小程序查询历史记录
     *
     * @param miniprogramQueryLog 小程序查询历史记录
     * @return 结果
     */
    @Override
    public int insertMiniprogramQueryLog(MiniprogramQueryLog miniprogramQueryLog) {
        miniprogramQueryLog.setCreateTime(DateUtils.getNowDate());
        return miniprogramQueryLogMapper.insertMiniprogramQueryLog(miniprogramQueryLog);
    }

    /**
     * 修改小程序查询历史记录
     *
     * @param miniprogramQueryLog 小程序查询历史记录
     * @return 结果
     */
    @Override
    public int updateMiniprogramQueryLog(MiniprogramQueryLog miniprogramQueryLog) {
        miniprogramQueryLog.setUpdateTime(DateUtils.getNowDate());
        return miniprogramQueryLogMapper.updateMiniprogramQueryLog(miniprogramQueryLog);
    }

    /**
     * 批量删除小程序查询历史记录
     *
     * @param logIds 需要删除的小程序查询历史记录主键
     * @return 结果
     */
    @Override
    public int deleteMiniprogramQueryLogByLogIds(Long[] logIds) {
        return miniprogramQueryLogMapper.deleteMiniprogramQueryLogByLogIds(logIds);
    }

    /**
     * 删除小程序查询历史记录信息
     *
     * @param logId 小程序查询历史记录主键
     * @return 结果
     */
    @Override
    public int deleteMiniprogramQueryLogByLogId(Long logId) {
        return miniprogramQueryLogMapper.deleteMiniprogramQueryLogByLogId(logId);
    }
}
